[Catalyst-commits] r7780 - / Catalyst-Devel/1.00/trunk/lib/Catalyst Catalyst-Devel/1.10/trunk/lib/Catalyst

zarquon at dev.catalyst.perl.org zarquon at dev.catalyst.perl.org
Fri May 23 23:20:27 BST 2008


Author: zarquon
Date: 2008-05-23 23:20:26 +0100 (Fri, 23 May 2008)
New Revision: 7780

Modified:
   /
   Catalyst-Devel/1.00/trunk/lib/Catalyst/Helper.pm
   Catalyst-Devel/1.10/trunk/lib/Catalyst/Helper.pm
Log:
 r13153 at zaphod:  kd | 2008-05-23 19:23:59 +1000
 changing to config::general in the correct version of catalyst::devel



Property changes on: 
___________________________________________________________________
Name: svk:merge
   - 1b129c88-ebf4-0310-add9-f09427935aba:/local/catalyst:4278
1c72fc7c-9ce4-42af-bf25-3bfe470ff1e8:/local/Catalyst:13137
3b9770f9-e80c-0410-a7de-cd203d167417:/local/catalyst:3514
dd8ad9ea-0304-0410-a433-df5f223e7bc0:/local/Catalyst:6909
   + 1b129c88-ebf4-0310-add9-f09427935aba:/local/catalyst:4278
1c72fc7c-9ce4-42af-bf25-3bfe470ff1e8:/local/Catalyst:13153
3b9770f9-e80c-0410-a7de-cd203d167417:/local/catalyst:3514
dd8ad9ea-0304-0410-a433-df5f223e7bc0:/local/Catalyst:6909

Modified: Catalyst-Devel/1.00/trunk/lib/Catalyst/Helper.pm
===================================================================
--- Catalyst-Devel/1.10/trunk/lib/Catalyst/Helper.pm	2008-05-23 22:12:02 UTC (rev 7779)
+++ Catalyst-Devel/1.10/trunk/lib/Catalyst/Helper.pm	2008-05-23 22:20:26 UTC (rev 7780)
@@ -553,7 +553,7 @@
 # Set flags and add plugins for the application
 #
 #         -Debug: activates the debug mode for very useful log messages
-#   ConfigLoader: will load the configuration from a YAML file in the
+#   ConfigLoader: will load the configuration from a Config::General file in the
 #                 application's home directory
 # Static::Simple: will serve static files from the application's root 
 #                 directory
@@ -862,7 +862,7 @@
 my $keepalive         = 0;
 my $restart           = $ENV{[% appenv %]_RELOAD} || $ENV{CATALYST_RELOAD} || 0;
 my $restart_delay     = 1;
-my $restart_regex     = '(?:/|^)(?!\.#).+(?:\.yml$|\.yaml$||\.conf|\.pm)$';
+my $restart_regex     = '(?:/|^)(?!\.#).+(?:\.yml$|\.yaml$|\.conf|\.pm)$';
 my $restart_directory = undef;
 my $follow_symlinks   = 0;
 




More information about the Catalyst-commits mailing list
--- Catalyst-Devel/1.00/trunk/lib/Catalyst/Helper.pm	2008-05-23 22:12:02 UTC (rev 7779)
+++ Catalyst-Devel/1.00/trunk/lib/Catalyst/Helper.pm	2008-05-23 22:20:26 UTC (rev 7780)
@@ -329,7 +329,7 @@
     my $dir       = $self->{dir};
     my $appprefix = $self->{appprefix};
     $self->render_file( 'config',
-        File::Spec->catfile( $dir, "$appprefix.yml" ) );
+        File::Spec->catfile( $dir, "$appprefix.conf" ) );
 }
 
 sub _mk_readme {
@@ -612,7 +612,7 @@
 # Set flags and add plugins for the application
 #
 #         -Debug: activates the debug mode for very useful log messages
 #   ConfigLoader: will load the configuration from a YAML file in the
 #                 application's home directory
 # Static::Simple: will serve static files from the application's root 
 #                 directory
@@ -623,7 +623,7 @@
 
 # Configure the application. 
 #
 # Note that settings in [% appprefix %].yml (or other external
 # configuration file that you set up manually) take precedence
 # over this when using ConfigLoader. Thus configuration
 # details given here can function as a default configuration,
@@ -738,7 +738,7 @@
 requires 'Catalyst::Plugin::Static::Simple';
 requires 'Catalyst::Action::RenderView';
 requires 'parent';
-requires 'YAML'; # This should reflect the config file format you've chosen
+requires 'Config::General'; # This should reflect the config file format you've chosen
                  # See Catalyst::Plugin::ConfigLoader for supported formats
 catalyst;
 
@@ -746,8 +746,9 @@
 auto_install;
 WriteAll;
 __config__
----
-name: [% name %]
+# rename this file to [% name %].yml and put a : in front of "name" if
+# you want to use yaml like in old versions of Catalyst
+name [% name %]
 __readme__
 Run script/[% appprefix %]_server.pl to test the application.
 __changes__
@@ -926,7 +927,7 @@
 my $keepalive         = 0;
 my $restart           = $ENV{[% appenv %]_RELOAD} || $ENV{CATALYST_RELOAD} || 0;
 my $restart_delay     = 1;
-my $restart_regex     = '(?:/|^)(?!\.#).+(?:\.yml$|\.yaml$|\.pm)$';
+my $restart_regex     = '(?:/|^)(?!\.#).+(?:\.yml$|\.yaml$|\.conf|\.pm)$';
 my $restart_directory = undef;
 my $follow_symlinks   = 0;
 
@@ -993,7 +994,7 @@
    -rd -restartdelay  delay between file checks
    -rr -restartregex  regex match files that trigger
                       a restart when modified
-                      (defaults to '\.yml$|\.yaml$|\.pm$')
+                      (defaults to '\.yml$|\.yaml$|\.conf|\.pm$')
    -restartdirectory  the directory to search for
                       modified files, can be set mulitple times
                       (defaults to '[SCRIPT_DIR]/..')
@@ -612,7 +612,7 @@
 #
 #         -Debug: activates the debug mode for very useful log messages
-#   ConfigLoader: will load the configuration from a YAML file in the
+#   ConfigLoader: will load the configuration from a Config::General file in the
 #                 application's home directory
 # Static::Simple: will serve static files from the application's root 
@@ -623,7 +623,7 @@
 # Configure the application. 
 #
-# Note that settings in [% appprefix %].yml (or other external
+# Note that settings in [% appprefix %].conf (or other external
 # configuration file that you set up manually) take precedence
 # over this when using ConfigLoader. Thus configuration

Modified: Catalyst-Devel/1.10/trunk/lib/Catalyst/Helper.pm
===================================================================